@@ -21,6 +21,15 @@ module Icalendar
         "#{behind? ? '-' : '+'}#{'%02d' % hours}#{'%02d' % minutes}#{'%02d' % seconds if seconds > 0}"
       end
 
+      def to_s
+        str = "#{behind? ? '-' : '+'}#{'%02d' % hours}:#{'%02d' % minutes}"
+        if seconds > 0
+          "#{str}:#{'%02d' % seconds}"
+        else
+          str
+        end
+      end
+
       private
 
       def zero_offset?
@@ -28,8 +37,7 @@ module Icalendar
       end
 
       def parse_fields(value)
-        value.gsub!(/\s+/, '')
-        md = /\A(?<behind>[+-])(?<hours>\d{2})(?<minutes>\d{2})(?<seconds>\d{2})?\z/.match value
+        md = /\A(?<behind>[+-])(?<hours>\d{2})(?<minutes>\d{2})(?<seconds>\d{2})?\z/.match value.gsub(/\s+/, '')
         {
           behind: (md[:behind] == '-'),
           hours: md[:hours].to_i,
